@@ -12,13 +12,12 @@ class TreeItemForm(forms.Form):
         - `tree_item`: ID of an initial tree item
 
     """
-
     choice_field_class = TreeItemChoiceField
 
     def __init__(self, *args, **kwargs):
         tree = kwargs.pop('tree', None)
         tree_item = kwargs.pop('tree_item', None)
-        super(TreeItemForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
         # autocomplete off - deals with Firefox form caching
         # https://bugzilla.mozilla.org/show_bug.cgi?id=46845
